flutter_supabase_chat_core
library
Classes
-
SupabaseChatController
-
Provides Supabase chat controller. Instance new class
SupabaseChatController to manage a chat.
-
SupabaseChatCore
-
Provides access to Supabase chat data. Singleton, use
SupabaseChatCore.instance to access methods.
-
SupabaseChatCoreConfig
-
Class that represents the chat config. Can be used for setting custom names
for rooms and users collections. Call
SupabaseChatCore.instance.setConfig
before doing anything else with SupabaseChatCore.instance if you want to
change the default collection names. When using custom names don't forget
to update your security rules and indexes.
-
UploadAssetResult
-
-
UserOnlineStateObserver
-
This widget takes care of observing the state of the application if it is foregrounded
or if it is reduced. At each state change it notifies on the Supabase Realtime channel the state
online/offline of the user
-
UserOnlineStatusWidget
-
This widget allows you to observe the online/offline status of a specific user
Functions
-
fetchUser(SupabaseClient instance, String userId, String usersTableName, String schema, {String? role})
→ Future<Map<String, dynamic>>
-
Fetches user from Firebase and returns a promise.
-
processRoomRow(Map<String, dynamic> data, User supabaseUser, SupabaseClient instance, String usersTableName, String schema)
→ Future<Room>
-
Returns a
types.Room created from Firebase document.
-
processRoomsRows(User supabaseUser, SupabaseClient instance, List rows, String usersTableName, String schema)
→ Future<List<Room>>
-
Returns a list of
types.Room created from Firebase query.
If room has 2 participants, sets correct room name and image.